@@ -19,6 +19,10 @@ def delete_dbl_spaces(value):
     return re.sub('\s+', ' ', value).strip();
 
 
+def null2blanck(str):
+    return '' if str == 'null' else str
+
+
 class Common:
     @staticmethod
     def get_size_file_str(value):
