@@ -3,6 +3,22 @@ from bitfield import BitHandler, Bit
 from isc_common import setAttr
 
 
+def DecimalToStr(value):
+    if value == None:
+        return value
+
+    try:
+        res = str(value)
+        res.split('.')
+        cel = res.split('.')[0]
+        float = StrToNumber(res.split('.')[1:][0])
+        if float > 0:
+            return f'{cel}.{float}'
+        return cel
+    except IndexError:
+        return value
+
+
 def StrToNumber(s1):
     if s1 == None:
         return None
